@@ -53,7 +53,8 @@ class instrument:
     def On(self):
         self.MaiTai.write('ON')
 
-
-
+    def Off(self):
+        self.Shutter(0)
+        self.MaiTai.write("OFF")
 
 
