@@ -18,6 +18,7 @@ class InstrumentWrapper(param.Parameterized):
     instrument_selected = param.ObjectSelector()
     button = pn.widgets.Button(name='Reload devices', button_type='primary')
     button2 = pn.widgets.Button(name="Initialize instrument", button_type='primary')
+    initialized = False
 
     def __init__(self, modules, name):
         super().__init__()
@@ -63,10 +64,11 @@ class InstrumentWrapper(param.Parameterized):
         module = self.devices[self.instrument_selected]["module"]
         self.instrument = self.modules[module]["module"].instrument(
             self.devices[self.instrument_selected]["port"])
+        initialized = True
 
     def view(self):
 
-        return pn.Column(self.param, self.button,self.button2)
+        return pn.Column(self.param, self.button, self.button2)
 
     def serve(self):
         self.view().show(port=5006)
